==> vue-alert-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/alert/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { iconClose, iconSuccess, iconError, iconHelp, iconWarning } from "@dft-vue-2-opentiny/vue-icon";
import "@dft-vue-2-opentiny/vue-theme/alert/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["icon", "type", "size", "description", "title", "closable", "center", "showIcon", "closeText"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconHelp: iconHelp(),
    IconWarning: iconWarning()
  },
  emits: ["close"],
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-transition-alert-fade"
    }
  }, [_vm.state.show ? _c("div", {
    class: ["tiny-alert", "tiny-alert--" + _vm.type, "tiny-alert--" + _vm.size, {
      "is-center": _vm.center
    }]
  }, [_vm.showIcon ? _c(_vm.state.getIcon, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-alert__icon"
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-alert__content"
  }, [_vm.size === "large" ? _c("div", {
    staticClass: "tiny-alert__title"
  }, [_vm._t("title", [_vm._v(" " + _vm._s(_vm.state.getTitle) + " ")])], 2) : _vm._e(), _c("div", {
    class: ["tiny-alert__description", {
      "is-hide": _vm.size === "large" && !_vm.description && !_vm.slots.description
    }]
  }, [_vm._t("description", [_vm._v(" " + _vm._s(_vm.description) + " ")])], 2), _vm.size === "large" ? _c("div", {
    staticClass: "tiny-alert__opration"
  }, [_vm._t("default")], 2) : _vm._e()]), !_vm.closeText && _vm.closable ? _c("icon-close", {
    staticClass: "tiny-svg-size tiny-alert__icon tiny-alert__close",
    on: {
      "click": _vm.handleClose
    }
  }) : !_vm.closeText && !_vm.closable ? _c("span", {
    staticClass: "is-custom"
  }, [_vm._t("close")], 2) : _vm.closeText && _vm.closable ? _c("span", {
    staticClass: "is-custom",
    on: {
      "click": _vm.handleClose
    }
  }, [_vm._v(_vm._s(_vm.closeText))]) : _vm._e()], 1) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-alert-2.23.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/alert/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconClose, iconSuccess, iconError, iconHelp, iconWarning, iconWarningTriangle } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/alert/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["icon", "type", "size", "description", "title", "closable", "center", "showIcon", "showTitle", "closeText", "customClass"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconHelp: iconHelp(),
    IconWarning: iconWarning(),
    IconWarningTriangle: iconWarningTriangle()
  },
  emits: ["close"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("transition", {
    attrs: {
      "name": "tiny-transition-alert-fade"
    }
  }, [_vm.state.show ? _c("div", {
    class: ["tiny-alert", "tiny-alert--" + _vm.type, "tiny-alert--" + _vm.size, {
      "is-center": _vm.center
    }, _vm.customClass]
  }, [_vm.showIcon ? _c(_vm.state.getIcon, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-alert__icon"
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-alert__content",
    class: {
      "close-hidden": !_vm.closable
    }
  }, [_vm.size === "large" && _vm.showTitle ? _c("div", {
    staticClass: "tiny-alert__title"
  }, [_vm._t("title", function() {
    return [_vm._v(" " + _vm._s(_vm.state.getTitle))];
  })], 2) : _vm._e(), _c("div", {
    class: ["tiny-alert__description", {
      "is-hide": _vm.size === "large" && !_vm.description && !_vm.slots.description
    }]
  }, [_vm._t("description", function() {
    return [_vm._v(" " + _vm._s(_vm.description) + " ")];
  })], 2), _vm.size === "large" ? _c("div", {
    staticClass: "tiny-alert__opration"
  }, [_vm._t("default")], 2) : _vm._e()]), !_vm.closeText && _vm.closable ? _c("icon-close", {
    staticClass: "tiny-svg-size tiny-alert__icon tiny-alert__close",
    on: {
      "click": _vm.handleClose
    }
  }) : !_vm.closeText && !_vm.closable ? _c("span", {
    staticClass: "is-custom"
  }, [_vm._t("close")], 2) : _vm.closeText && _vm.closable ? _c("span", {
    staticClass: "is-custom",
    on: {
      "click": _vm.handleClose
    }
  }, [_vm._v(_vm._s(_vm.closeText))]) : _vm._e()], 1) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
